import java.io.*;
import java.util.*;
import java.util.jar.*;

class Main {
    public static void main(String[] args) {
        if (args.length < 2) {
            System.out.println("Usage: java Main <jar-file> <file1>...");
            System.exit(1);
        }

        try {
            // Create the manifest.
            Manifest man = new Manifest();
            man.getMainAttributes().put(Attributes.Name.MANIFEST_VERSION, "1.0");

            for (int i=1; i<args.length; i++) {
                File f = new File(args[i]);
                Attributes attr = new Attributes();

                attr.put(new Attributes.Name("Date"), 
                    new Date(f.lastModified()).toString());
                man.getEntries().put(entryName(f), attr);
            }

            // Dump manifest.
            man.write(System.out);
        
            JarOutputStream jos = new JarOutputStream(
                new FileOutputStream(args[0]), man);

            // Now save all the list files in the JAR.
            byte[] buf = new byte[1024];
            int len;
            for (int i=1; i<args.length; i++) {
                File f = new File(args[i]);
                FileInputStream fis = new FileInputStream(f);
                jos.putNextEntry(new JarEntry(entryName(f)));

                // Now read and write the jar entry data.
                while ((len = fis.read(buf)) >= 0) {
                    jos.write(buf, 0, len);
                }
            }
            jos.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    // Converts f's pathname to a form acceptable to ZIP files.
    // In particular, file separators are converted to forward slashes.
    static String entryName(File f) throws IOException {
        return f.getName().replace(File.separatorChar, '/');
    }
}
