import java.lang.ref.*;
import java.io.*;
import java.util.*;

class Main {
    public static void main(String[] args) throws IOException {
        Set isUsed = new HashSet();
        Object o = new Object();
        WatcherThread thread = new WatcherThread(isUsed);
        thread.start();

        thread.watch("A", o);
        System.out.println( isUsed.contains("A") );   // true

        // Wait a few seconds before making o unused.
        try {
            Thread.sleep(5000);
        } catch (Exception e) {
            e.printStackTrace();
        }
        o = null;

        // Use all available memory to force a garbage-collection.
        eatMemory(new LinkedList());

        System.out.println( isUsed.contains("A") );   // false
    }
    static void eatMemory(LinkedList l) {
        try {
            l.add(new double[100000]);
            eatMemory(l);
        } catch (OutOfMemoryError e) {
            System.out.println("**** OUT OF MEMORY ****");
            l.clear();
            System.gc();
        }
    }
}

class WatcherThread extends Thread {
    ReferenceQueue refq = new ReferenceQueue();
    Map map = new HashMap();
    Set set;

    public WatcherThread(Set s) {
        set = s;
    }

    public void watch(String label, Object o) {
        Reference r = new PhantomReference(o, refq);
        set.add(label);
        map.put(r, label);
    }
    
    public void run() {
        try {
            while (true) {
                // Wait for phantom reference notification.
                Reference r = refq.remove();

                r.clear();
                set.remove(map.get(r));
                map.remove(r);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
