import java.lang.reflect.*;
import java.util.*;

class Main {
    public static void main(String[] args) {
        // Load in the p.C class.
        new p.C();

        // Dump the package list for Main's class loader.
        System.out.println("Packages loaded by Main's class loader");
        Package[] pkgs = Package.getPackages();
        printPackages(pkgs);

        System.out.println(Package.getPackage("p")!=null);   // true

        // Now dump the package list of the system class loader.
        System.out.println("Packages loaded by the system class loader.");
        pkgs = (Package[])invokeMethod(
            Package.class, "getSystemPackages", new Object[0]);
        printPackages(pkgs);

        System.out.println(invokeMethod(ClassLoader.getSystemClassLoader(),
            "getPackage", new Object[]{"p"})!=null);         // false
    }

    public static void printPackages(Package[] pkgs) {
        // First sort the list.
        Arrays.sort(pkgs, 
            new Comparator() {
                public int compare(Object a, Object b) {
                    return ((Package)a).getName().compareTo(
                        ((Package)b).getName());
                }
            }
        );
        for (int i=0; i<pkgs.length; i++) {
            System.out.print("  " + pkgs[i].getName());
            if (pkgs[i].isSealed()) {
                System.out.print(" *sealed*");
            }
            System.out.println();
        }
    }

    public static Object invokeMethod(
            Object o, String name, Object[] params) {
        // Create parameter type array.
        Class[] paramTypes = new Class[params.length];
        for (int i=0; i<params.length; i++) {
            paramTypes[i] = params[i].getClass();
        }
        // Retrieve the object o's class, unless the o
        // is itself a class.
        Class c = o instanceof Class ? (Class)o : o.getClass();

        // Find the declared method by checking all superclasses as well.
        while (c != null) {
            try {
                Method m = c.getDeclaredMethod(name, paramTypes);
                m.setAccessible(true);

                // Invoke the method an return the results.
                return m.invoke(o, params);
            } catch (NoSuchMethodException e) {
                c = c.getSuperclass();
            } catch (Exception e) {
                break;
            }
        }
        return null;
    }
}
