import java.io.*;
import java.util.*;

class Dir {
    String[] files;

    Dir(String dir) {
        try {
            files = new File(dir).list();
        } catch (Exception e) {
            files = null;
        }
    }
    List getList() {
        return new AbstractSequentialList() {
            public int size() {
                return files == null ? 0 : files.length;
            }
            public ListIterator listIterator(final int index) {
                if (index < 0 || index > size()) {
                    throw new IndexOutOfBoundsException();
                }
                // This iterator is not fail-fast.
                return new ListIterator() {
                    private int cursor = index;

                    public void add(Object e) {
                        throw new UnsupportedOperationException();
                    }

                    public boolean hasNext() {
                        return cursor < size();
                    }

                    public boolean hasPrevious() {
                        return cursor > 0;
                    }

                    public Object next() {
                        if (cursor >= size()) {
                            throw new NoSuchElementException();
                        }
                        return files[cursor++];
                    }

                    public int nextIndex() {
                        return cursor;
                    }

                    public Object previous() {
                        if (cursor <= 0) {
                            throw new NoSuchElementException();
                        }
                        return files[--cursor];
                    }

                    public int previousIndex() {
                        return cursor-1;
                    }

                    public void remove() {
                        throw new UnsupportedOperationException();
                    }

                    public void set(Object e) {
                        throw new UnsupportedOperationException();
                    }
                };
            }
        };

    }

    public static void main(String[] args) {
        List list = new Dir(args[0]).getList();
        for (Iterator it=list.iterator(); it.hasNext(); ) {
            System.out.println(it.next());
        }
    }
}
