import java.io.*;
import java.util.*;
import java.util.jar.*;
import java.security.*;
import java.security.interfaces.*;
import java.security.cert.X509Certificate;
import java.security.cert.Certificate;

class Main {
    public static void main(String[] args) {
        if (args.length < 1) {
            System.err.println("Usage: java Main <jar-file>");
            System.exit(1);
        } 

        try {
            JarFile jf = new JarFile(args[0], true);
            // List the names of all entries in the jar file.
            for (Enumeration e=jf.entries(); e.hasMoreElements(); ) {
                JarEntry je = (JarEntry)e.nextElement();

                // This step is necessary, otherwise getCertificates()
                // always returns null.
                InputStream is = jf.getInputStream(je);
                is.skip(je.getSize());

                Certificate[] cert = je.getCertificates();
                if (cert != null) {
                    System.out.println(je);
                    printCertificate(cert);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    // Print some details about the certificate.
    static void printCertificate(java.security.cert.Certificate[] certs) {
        for (int i=0; i<certs.length; i++) {
            System.out.println("  Type: "+certs[i].getType());
            if (certs[i] instanceof X509Certificate) {
                X509Certificate c = (X509Certificate)certs[i];
                    
                System.out.println("  Issuer: " + c.getIssuerDN().getName());
                System.out.println("  Subject: " + c.getSubjectDN().getName());
                System.out.println("  Serial#: " + c.getSerialNumber());
                System.out.println("  Expires: " + c.getNotAfter());
            }

            PublicKey pk = certs[i].getPublicKey();
            if (pk instanceof DSAPublicKey) {
                DSAPublicKey dpk = (DSAPublicKey)pk;
                System.out.println("  Algorithm: " + dpk.getAlgorithm());
                System.out.println("  Format: " + dpk.getFormat());
            }
        }
    }
}
