import java.io.*;
import java.util.*;
import java.util.jar.*;

class Main {
    public static void main(String[] args) {
        if (args.length < 1) {
            System.out.println("Usage: java Main <jar-file>");
            System.exit(1);
        }

        try {
            JarInputStream jis = new JarInputStream(
                new FileInputStream(args[0]));

            // Print the manifest.
            Manifest man = jis.getManifest();
            if (man != null) {
                printManifest(man);
            }
            System.out.println("\n");

            // Print the attributes for each jar entry.
            JarEntry je;
            while ((je = jis.getNextJarEntry()) != null) {
                System.out.println("++++++++++ " + je);
                if (je.getAttributes() != null) {
                    printAttributes(je.getAttributes());
                }
            }
            jis.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    static void printManifest(Manifest man) {
        System.out.println("---------- Main Attributes");
        printAttributes(man.getMainAttributes());
        for (Iterator it=man.getEntries().keySet().iterator(); it.hasNext(); )
        {
            String ename = (String)it.next();
            System.out.println("---------- " + ename);
            printAttributes(man.getAttributes(ename));
        }
    }

    static void printAttributes(Attributes attr) {
        for (Iterator it=attr.keySet().iterator(); it.hasNext(); ) {
            Object key = it.next();
            System.out.println(key+": "+attr.get(key));
        }
    }
}
