import java.io.*;
import java.util.*;
import java.util.jar.*;

class Main {
    public static void main(String[] args) {
        Manifest man = new Manifest();
        man.getMainAttributes().put(Attributes.Name.MANIFEST_VERSION, "1.0");
        Attributes attr = new Attributes();
        attr.put("Sealed", "false");
        man.getEntries().put("Main.class", attr);
        Attributes attr2 = new Attributes();
        attr2.put("Desc", "Example Source");
        man.getEntries().put("Main.java", attr2);

        Manifest manCopy = (Manifest)man.clone();
        printAttributes(manCopy.getMainAttributes());// Manifest-Version: 1.0
        System.out.println(man.equals(manCopy));    // true

        // Changing a main attribute value in the original doesn't change clone
        man.getMainAttributes().put(Attributes.Name.MANIFEST_VERSION, "2.0");
        printAttributes(manCopy.getMainAttributes());// Manifest-Version: 1.0
        System.out.println(man.equals(manCopy));     // false

        // Clearing the original also does not affect the clone.
        man.clear();
        printAttributes(manCopy.getMainAttributes());// Manifest-Version: 1.0

        // Deleting a manifest entry in the original doesn't change clone
        manCopy = (Manifest)man.clone();
        man.getEntries().remove("Main.class");
        System.out.println(man.equals(manCopy));     // false

        // Modifying a manifest entry in the original does change clone
        // Note that Main.java did not have a "Sealed" attribute before now
        manCopy = (Manifest)man.clone();
        Attributes mj = man.getAttributes("Main.java");
        mj.put("Sealed", "false");
        printAttributes(man.getAttributes("Main.java"));     // Desc, Sealed
        printAttributes(manCopy.getAttributes("Main.java")); // Desc, Sealed
        System.out.println(man.equals(manCopy));     // true

    }

    static void printAttributes(Attributes attr) {
        for (Iterator it=attr.keySet().iterator(); it.hasNext(); ) {
            Object key = it.next();
            System.out.println(key + ": " + attr.get(key));
        }
    }
}
